# -*- coding: utf-8 -*-
"""
    flask.ext.fillin
    ~~~~~~~~~~~~~~~~

    Adds utilities for testing form in flask applications.

    :copyright: (c) 2012 by Christoph Heer.
    :license: BSD, see LICENSE for more details.
"""

from wrapper import FormWrapper